==> haskell-summoner-2.0.1.1-664-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-9el5pNd8GNe7gdTnM0ZyXD
key:                  summoner-2.0.1.1-9el5pNd8GNe7gdTnM0ZyXD
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  8cb9ea0b420a5a48d89da4a065075ca9
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner
hs-libraries:         HSsummoner-2.0.1.1-9el5pNd8GNe7gdTnM0ZyXD
depends:
    base-4.17.2.1 relude-1.2.2.2-CLBKzWvEwmeLmNDXtB9DL8
    aeson-2.1.2.1-1NeIvw5bSkQ9apxHmCtPBl
    colourista-0.1.0.2-HfS2hBmaaOG1OzBheWzhXB containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    generic-data-1.1.0.2-3VP0a3IKVUy3eaEwVQkSAk
    gitrev-1.3.1-EAQEu0I0MYZ3NOvBCjPIAO
    neat-interpolation-0.5.1.4-AqAGoaFnKmBJSKGfBkKLNl
    optparse-applicative-0.18.1.0-EO4j3VaswTtGiqiAFplF0k
    process-1.6.18.0 shellmet-0.0.5.0-UC26fQ9PDMI281FwJbmox text-2.0.2
    time-1.12.2 tomland-1.3.3.3-KQ3zkPxmV4UBuJMGs9Hcfm
    validation-selective-0.2.0.0-CllywlAgz3DSUfPdCmc05

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-2.0.1.1-665-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-9QbnUXTTg9C6ujZ7mlNSVp
key:                  summoner-2.0.1.1-9QbnUXTTg9C6ujZ7mlNSVp
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  25608ff2463a06a0f10802b116602398
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner
hs-libraries:         HSsummoner-2.0.1.1-9QbnUXTTg9C6ujZ7mlNSVp
depends:
    base-4.17.2.1 relude-1.2.2.2-LDdQ7U5rZyvJ2JyPYN4KTs
    aeson-2.1.2.1-Kx5U0b11hXDAcrJPuBeHuf
    colourista-0.1.0.2-iEhaPGQoLp2ghaUG04Yu2 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    generic-data-1.1.0.2-Hiw2beHysiCFb9rW6GbBBU
    gitrev-1.3.1-EAQEu0I0MYZ3NOvBCjPIAO
    neat-interpolation-0.5.1.4-A1q9j1xY2XYItT2rjmlo0M
    optparse-applicative-0.18.1.0-1Ar9aW9o69J8KQyhUKGEja
    process-1.6.18.0 shellmet-0.0.5.0-GSM3xfWv4COKacbGbR81Pq text-2.0.2
    time-1.12.2 tomland-1.3.3.3-6K0ktHCIeWSJ1Egt83b98b
    validation-selective-0.2.0.0-L6cow80zc3wDob0W6lgTsq

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
